package com.zy.omp.config;

import com.zy.omp.config.interceptor.AuthInterceptor;
import com.zy.omp.config.interceptor.VerifyInterceptor;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Profile;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * 配置拦截器
 *
 * @author chenyi
 * Create on 2019/10/10
 */
@Profile("prod")
@Configuration
public class InterceptorConfig implements WebMvcConfigurer {
    /**
     * 身份验证拦截器
     */
    @Resource
    private VerifyInterceptor verifyInterceptor;
    @Resource
    private AuthInterceptor authInterceptor;

    private static List<String> whiteList = new ArrayList<>();

    static {
        whiteList.add("omp/api/pc/admin/login.do");
        whiteList.add("/common/**");
    }

    /**
     * 添加自定义拦截器
     */
    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        registry.addInterceptor(verifyInterceptor)
                .addPathPatterns("omp/api/pc/**")
                .excludePathPatterns("/common/**");

        registry.addInterceptor(authInterceptor)
                .addPathPatterns("omp/api/pc/**")
                .excludePathPatterns(whiteList);
    }
}
