package com.zy.omp.controller.wx;

import com.zy.omp.common.Constant;
import com.zy.omp.common.ServerResponse;
import com.zy.omp.common.controller.BaseController;
import com.zy.omp.model.DeviceSet;
import com.zy.omp.model.News;
import com.zy.omp.service.RelationService;
import com.zy.omp.service.SetService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * 设备设置相关
 *
 * @author yang xiao kun
 * create on 2021/1/21
 */
@Slf4j
@RestController
@RequestMapping("omp/api/wx/set")
public class SetController extends BaseController {

    @Resource
    private SetService setService;
    @Resource
    private RelationService relationService;

    /**
     * 校验设备是否是该用户的设备
     */
    private boolean verify(DeviceSet param) {
        boolean flag = relationService.checkBelong(param.getOpenNum(), getOpenId());
        if (!flag) {
            log.error("非法请求 -- openId: " + getOpenId() + "openNum: " + param.getOpenNum());
        }
        return flag;
    }

    /**
     * 设置音量
     */
    @PostMapping("volume.do")
    public ServerResponse setVolume(DeviceSet param) {
        if (verify(param)) setService.set(Constant.M_CODE_VOLUME, param);
        return ServerResponse.createBySuccess();
    }

    /**
     * 设置定位频率
     */
    @PostMapping("gpsRate.do")
    public ServerResponse gpsRate(DeviceSet param) {
        if (verify(param)) setService.set(Constant.M_CODE_GPS_RATE, param);
        return ServerResponse.createBySuccess();
    }

    /**
     * 自动接听
     *
     * @param param 设置参数
     */
    @PostMapping("autoAnswer.do")
    public ServerResponse setAutoAnswer(DeviceSet param) {
        if (verify(param)) setService.set(Constant.M_CODE_AUTO_ANSWER, param);
        return ServerResponse.createBySuccess();
    }

    /**
     * 设置语音播报
     */
    @PostMapping("news.do")
    public ServerResponse setNews(News news) {
        if (relationService.checkBelong(getOpenId(), news.getOpenNum())) {
            log.error("非法请求 -- openId: " + getOpenId() + "openNum: " + news.getOpenNum());
        }
        setService.saveNews(news);
        return ServerResponse.createBySuccess();
    }

    /**
     * 设置SOS紧急呼叫
     */
    @PostMapping("sos.do")
    public ServerResponse setSOS(DeviceSet param) {
        if (verify(param)) setService.set(Constant.M_CODE_SOS, param);
        return ServerResponse.createBySuccess();
    }

    /**
     * 设置持续定位
     */
    @PostMapping("continue.do")
    public ServerResponse setContinue(DeviceSet param) {
        if (verify(param)) setService.set(Constant.M_CODE_CONTINUE_GPS, param);
        return ServerResponse.createBySuccess();
    }
}
